### GraphGT: Machine Learning Datasets for Graph Generation and Transformation

[![website](https://img.shields.io/badge/website-live-brightgreen)](https://graphgt.github.io/)
[![GitHub Repo stars](https://img.shields.io/github/stars/yuanqidu/GraphGT)](https://github.com/yuanqidu/GraphGT/stargazers)

[**Dataset Website**](https://graphgt.github.io/) | [**Paper**](https://graphgen-dc.github.io/)

## Installation

### Using `pip`

To install the core environment dependencies of GraphGT, use `pip`:

```bash
pip install GraphGT
```

**Note**: GraphGT is in the beta release. Please update your local copy regularly by

```bash
pip install GraphGT --upgrade
```

## Cite Us

If you use our dataset in your work, please cite us:

```
@article{graphgt,
  title={GraphGT: Machine Learning Datasets for Graph Generation and Transformation},
  author={Du, Yuanqi and Wang, Shiyu and Guo, Xiaojie and Cao, Hengning and Jiang, Junji and Hu, Shujie and Varala, Aishwarya and Angirekula, Abhinav and Zhao, Liang},
  year={2021}
}
```

## Team
[Yuanqi Du](https://yuanqidu.github.io/) (Leader), Shiyu Wang, Xiaojie Guo, Hengning Cao, Shujie Hu, Junji Jiang, Aishwarya Varala, Abhinav Angirekula, [Liang Zhao](http://cs.emory.edu/~lzhao41/) (Advisor)

## Contact
Send us an [email](mailto:ydu6@gmu.edu) or open an issue.
